# -*- coding: utf-8 -*-

from nose.plugins import Plugin


# http://readthedocs.org/docs/nose/en/latest/plugins/interface.html
class DDFSetup(Plugin):
    "python manage.py test --with-ddf-setup"
    name = 'ddf-setup'
    enabled = True

    _error_message = None

    def begin(self):
        "Called before any tests are collected or run. Use this to perform any setup needed before testing begins."
        try:
            import ddf_setup
        except ImportError as e:
            self._error_message = str(e)

    def report(self, stream):
        """Called after all error output has been printed. Print your
        plugin's report to the provided stream. Return None to allow
        other plugins to print reports, any other value to stop them.

        :param stream: stream object; send your output here
        :type stream: file-like object
        """
        if self._error_message:
            stream.write('\nDDF Setup error: %s\n' % self._error_message)



# -*- coding: utf-8 -*-
from django.test import TestCase

from django_dynamic_fixture import G, N, teach, DDFLibrary
from django_dynamic_fixture.models_test import ModelForDDFSetup


class ModuleDDFSetUpTest(TestCase):
    def setUp(self):
        DDFLibrary.instance = DDFLibrary() # singleton object is cleared by another tests
        teach(ModelForDDFSetup, integer=9999) # using EXCLUSIVE_DDF_LIBRARY

    def tearDown(self):
        DDFLibrary.instance = DDFLibrary()

    def test_setup_module_load_before_any_test_of_this_module(self):
        instance = G(ModelForDDFSetup)
        assert instance.integer == 9999


class ApplicationDDFSetupTest(TestCase):
    def setUp(self):
        DDFLibrary.instance = DDFLibrary()
        teach(ModelForDDFSetup, integer=1000, ddf_lesson='test1')
        teach(ModelForDDFSetup, integer=1001)
        teach(ModelForDDFSetup, integer=1002, ddf_lesson='test2')

    def tearDown(self):
        DDFLibrary.instance = DDFLibrary()

    def test_ddf_setup_will_load_initial_lessons(self):
        instance = G(ModelForDDFSetup)
        assert instance.integer == 1001
        instance = G(ModelForDDFSetup, ddf_lesson='test1')
        assert instance.integer == 1000
        instance = G(ModelForDDFSetup, ddf_lesson='test2')
        assert instance.integer == 1002



# -*- coding: utf-8 -*-

from nose.plugins import Plugin


# http://readthedocs.org/docs/nose/en/latest/plugins/interface.html
class Queries(Plugin):
    "python manage.py test --with-queries"
    name = 'queries'
    _queries_by_test_methods = []

    def configure(self, options, conf):
        """
        Called after the command line has been parsed, with the parsed options and the config container. 
        Here, implement any config storage or changes to state or operation that are set by command line options.
        DO NOT return a value from this method unless you want to stop all other plugins from being configured.
        """
        super(Queries, self).configure(options, conf)
        if self.enabled:
            from django.db import connection
            connection.use_debug_cursor = True

    def beforeTest(self, test):
        "Called before the test is run (before startTest)."
        from django.db import connection
        self.initial_amount_of_queries = len(connection.queries)

    def afterTest(self, test):
        "Called after the test has been run and the result recorded (after stopTest)."
        from django.db import connection
        self.final_amount_of_queries = len(connection.queries)
        self._queries_by_test_methods.append((test, self.final_amount_of_queries - self.initial_amount_of_queries))

    def report(self, stream):
        """Called after all error output has been printed. Print your
        plugin's report to the provided stream. Return None to allow
        other plugins to print reports, any other value to stop them.

        :param stream: stream object; send your output here
        :type stream: file-like object
        """
        stream.write('\nREPORT OF AMOUNT OF QUERIES BY TEST:\n')
        for x in self._queries_by_test_methods:
            testcase = x[0]
            queries = x[1]
            stream.write('\n%s: %s' % (testcase, queries))
        stream.write('\n')



#from distutils.core import setup
from setuptools import setup, find_packages

# http://guide.python-distribute.org/quickstart.html
# python setup.py sdist
# Create a .pypirc file in ~ dir (cp .pypirc ~)
# python setup.py register
# python setup.py sdist upload
# pip install django-dynamic-fixture
# pip install django-dynamic-fixture --upgrade --no-deps
# Manual upload to PypI
# http://pypi.python.org/pypi/django-dynamic-fixture
# Go to 'edit' link
# Update version and save
# Go to 'files' link and upload the file

VERSION = '3.0.3'

tests_require = [
]

install_requires = [
    'six'
]

setup(name='django-dynamic-fixture',
      url='https://github.com/paulocheque/django-dynamic-fixture',
      author="paulocheque",
      author_email='paulocheque@gmail.com',
      keywords='python django testing fixture',
      description='A full library to create dynamic model instances for testing purposes.',
      license='MIT',
      classifiers=[
          'Framework :: Django',
          'Operating System :: OS Independent',
          'Topic :: Software Development',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: 3.6',
          'Programming Language :: Python :: 3.7',
          'Programming Language :: Python :: 3.8',
          'Programming Language :: Python :: Implementation :: PyPy',
      ],

      version=VERSION,
      install_requires=install_requires,
      tests_require=tests_require,
      test_suite='pytest',
      extras_require={'test': tests_require},

      entry_points={ 'nose.plugins': ['queries = queries:Queries', 'ddf_setup = ddf_setup:DDFSetup'] },
      packages=find_packages(),
)

